# MetricsRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**start_date** | **str** | start date of the period, in YYYY-MM-DD format |
**end_date** | **str** | end date of the period, in YYYY-MM-DD format |
**package_name** | **str** | package name to filter for | [optional]


[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


